// a_cseng.h           
//
// The english alphabet
//a_NOTE: ENG is the common item that can be used in a macro assign!
//a_NOTE: A in the diagrams means always set to 1, as in (0,0) of every character

#ifndef CSET_ENG

//a_Constants and MACROs
#include "a_predef.h"

#pragma message( "Including " __FILE__ )

#define CSET_ENG                0x1      //a_Let the ACharSetList know it is included for use
#define CSET_TYPE_ENG           'E'      //a_CharSet identifier
#define CSET_MAPSIZE_ENG        53       //a_# of arrays and hence map entries
#define CSET_ARRAYSIZE_ENG      32       //a_32 BYTEs per character array
#define CSET_CHARSIZE_X_ENG     16       //a_Width; including first column for info
#define CSET_CHARSIZE_Y_ENG     16       //a_Height; including the first row for info
#define CSET_CHARBASELINE_ENG   14       //a_Suggested baseline for all characters (from top)
#define CSET_CHARLINEHEIGHT_ENG 16       //a_Suggested height of the line to include all characters without clipping

static BYTE BYTEARRAY_MAP_ENG[CSET_MAPSIZE_ENG + 0x1]  = " ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";

//a_Each entry is a 16x16 bits
//a_Row 0 contains 1 bit for the rightmost X coordinate
//a_Column 0 contains 2 set bits, first for the baseline and second for lowest Y coordinate
//a_ if only one found, both assumed to be equal
//a_Baseline is used to align characters that are Y osition dependent (ie. sub/super script, lowecase, etc...)
//a_The actual character starts at (1,1) not (0,0), so actual usable size is actually 15x15
//a_First row and column will be zeroed out to provide spacing of 1 bit in X and Y
static BYTE BYTEMATRIX_CHARSET_ENG[CSET_MAPSIZE_ENG][CSET_ARRAYSIZE_ENG] =
{
  //a_' ' -   (space)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x81, 0x00,
    /*1 O............... */ 0x80, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |............... */ 0X00, 0x00,
    /*4 |............... */ 0x00, 0x00,
    /*5 |............... */ 0X00, 0x00,
    /*6 |............... */ 0x00, 0x00,
    /*7 |............... */ 0x00, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'A' - A
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |...X........... */ 0x08, 0x00,
    /*2 |..X.X.......... */ 0x14, 0x00,
    /*3 |.X...X......... */ 0X22, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 |X.....X........ */ 0x41, 0x00,
    /*8 |XXXXXXX........ */ 0x7F, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A |X.....X........ */ 0x41, 0x00,
    /*B OX.....X........ */ 0xC1, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'B' - B
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXX........... */ 0x78, 0x00,
    /*2 |X...X.......... */ 0x44, 0x00,
    /*3 |X....X......... */ 0X42, 0x00,
    /*4 |X....X......... */ 0x42, 0x00,
    /*5 |X...X.......... */ 0X44, 0x00,
    /*6 |XXXXX.......... */ 0x7C, 0x00,
    /*7 |X....X......... */ 0x44, 0x00,
    /*8 |X.....X........ */ 0x42, 0x00,
    /*9 |X.....X........ */ 0x42, 0x00,
    /*A |X....X......... */ 0x44, 0x00,
    /*B OXXXXX.......... */ 0xFC, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'C' - C
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |..XXXX......... */ 0x1E, 0x00,
    /*2 |.X....X........ */ 0x21, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |X.............. */ 0x40, 0x00,
    /*7 |X.............. */ 0x40, 0x00,
    /*8 |X.............. */ 0x40, 0x00,
    /*9 |X.............. */ 0x40, 0x00,
    /*A |.X....X........ */ 0x21, 0x00,
    /*B O..XXXX......... */ 0x9E, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'D' - D
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXX.......... */ 0x7C, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 |X.....X........ */ 0x41, 0x00,
    /*8 |X.....X........ */ 0x41, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A |X....X......... */ 0x42, 0x00,
    /*B OXXXXX.......... */ 0xFC, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },
  //a_'E' - E
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXXX........ */ 0x7F, 0x00,
    /*2 |X.............. */ 0x40, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |XXXXX.......... */ 0x7C, 0x00,
    /*7 |X.............. */ 0x40, 0x00,
    /*8 |X.............. */ 0x40, 0x00,
    /*9 |X.............. */ 0x40, 0x00,
    /*A |X.............. */ 0x40, 0x00,
    /*B OXXXXXXX........ */ 0xFF, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },
  //a_'F' - F
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXXX........ */ 0x7F, 0x00,
    /*2 |X.............. */ 0x40, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |XXXXX.......... */ 0x7C, 0x00,
    /*7 |X.............. */ 0x40, 0x00,
    /*8 |X.............. */ 0x40, 0x00,
    /*9 |X.............. */ 0x40, 0x00,
    /*A |X.............. */ 0x40, 0x00,
    /*B OX.............. */ 0xC0, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'G' - G
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |..XXXX......... */ 0x1E, 0x00,
    /*2 |.X....X........ */ 0x21, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |X.............. */ 0x40, 0x00,
    /*7 |X...XXX........ */ 0x47, 0x00,
    /*8 |X.....X........ */ 0x41, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A |.X....X........ */ 0x21, 0x00,
    /*B O..XXXX......... */ 0x9E, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'H' - H
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |XXXXXXX........ */ 0x7F, 0x00,
    /*7 |X.....X........ */ 0x41, 0x00,
    /*8 |X.....X........ */ 0x41, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A |X.....X........ */ 0x41, 0x00,
    /*B OX.....X........ */ 0xC1, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'I' - I
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXXX........ */ 0x7F, 0x00,
    /*2 |...X........... */ 0x08, 0x00,
    /*3 |...X........... */ 0X08, 0x00,
    /*4 |...X........... */ 0x08, 0x00,
    /*5 |...X........... */ 0X08, 0x00,
    /*6 |...X........... */ 0x08, 0x00,
    /*7 |...X........... */ 0x08, 0x00,
    /*8 |...X........... */ 0x08, 0x00,
    /*9 |...X........... */ 0x08, 0x00,
    /*A |...X........... */ 0x08, 0x00,
    /*B OXXXXXXX........ */ 0xFF, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'J' - J
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXXX........ */ 0x7F, 0x00,
    /*2 |......X........ */ 0x01, 0x00,
    /*3 |......X........ */ 0X01, 0x00,
    /*4 |......X........ */ 0x01, 0x00,
    /*5 |......X........ */ 0X01, 0x00,
    /*6 |......X........ */ 0x01, 0x00,
    /*7 |......X........ */ 0x01, 0x00,
    /*8 |......X........ */ 0x01, 0x00,
    /*9 |......X........ */ 0x01, 0x00,
    /*A |X....X......... */ 0x42, 0x00,
    /*B O.XXXX.......... */ 0xBC, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'K' - K
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |X...X.......... */ 0X44, 0x00,
    /*4 |X..X........... */ 0x48, 0x00,
    /*5 |X.X............ */ 0X50, 0x00,
    /*6 |XX............. */ 0x60, 0x00,
    /*7 |X.X............ */ 0x50, 0x00,
    /*8 |X..X........... */ 0x48, 0x00,
    /*9 |X...X.......... */ 0x44, 0x00,
    /*A |X....X......... */ 0x42, 0x00,
    /*B OX.....X........ */ 0xC1, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'L' - L
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.............. */ 0x40, 0x00,
    /*2 |X.............. */ 0x40, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |X.............. */ 0x40, 0x00,
    /*7 |X.............. */ 0x40, 0x00,
    /*8 |X.............. */ 0x40, 0x00,
    /*9 |X.............. */ 0x40, 0x00,
    /*A |X.............. */ 0x40, 0x00,
    /*B OXXXXXXX........ */ 0xFF, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'M' - M
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |XX...XX........ */ 0x63, 0x00,
    /*3 |XX...XX........ */ 0X63, 0x00,
    /*4 |X.X.X.X........ */ 0x55, 0x00,
    /*5 |X.X.X.X........ */ 0X55, 0x00,
    /*6 |X..X..X........ */ 0x49, 0x00,
    /*7 |X..X..X........ */ 0x49, 0x00,
    /*8 |X.....X........ */ 0x41, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A |X.....X........ */ 0x41, 0x00,
    /*B OX.....X........ */ 0xC1, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_' ' - 
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |XX....X........ */ 0x61, 0x00,
    /*3 |XX....X........ */ 0X61, 0x00,
    /*4 |X.X...X........ */ 0x51, 0x00,
    /*5 |X.X...X........ */ 0X51, 0x00,
    /*6 |X..X..X........ */ 0x49, 0x00,
    /*7 |X..X..X........ */ 0x49, 0x00,
    /*8 |X...X.X........ */ 0x45, 0x00,
    /*9 |X...X.X........ */ 0x45, 0x00,
    /*A |X....XX........ */ 0x43, 0x00,
    /*B OX....XX........ */ 0xC3, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'O' - O
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 |X.....X........ */ 0x41, 0x00,
    /*8 |X.....X........ */ 0x41, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A |X.....X........ */ 0x41, 0x00,
    /*B O.XXXXX......... */ 0xBE, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'P' - P
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXX......... */ 0x7E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |XXXXXX......... */ 0x7E, 0x00,
    /*7 |X.............. */ 0x40, 0x00,
    /*8 |X.............. */ 0x40, 0x00,
    /*9 |X.............. */ 0x40, 0x00,
    /*A |X.............. */ 0x40, 0x00,
    /*B OX.............. */ 0xC0, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'O' - O
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 |X.....X........ */ 0x41, 0x00,
    /*8 |X.....X........ */ 0x41, 0x00,
    /*9 |X..X..X........ */ 0x49, 0x00,
    /*A |X...X.X........ */ 0x45, 0x00,
    /*B O.XXXXXX........ */ 0xBF, 0x00,
    /*C |.....X......... */ 0x02, 0x00,
    /*D O......X........ */ 0x81, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'R' - R
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXX......... */ 0x7E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |XXXXXX......... */ 0x7E, 0x00,
    /*7 |X.X............ */ 0x50, 0x00,
    /*8 |X..X........... */ 0x48, 0x00,
    /*9 |X...X.......... */ 0x44, 0x00,
    /*A |X....X......... */ 0x42, 0x00,
    /*B OX.....X........ */ 0xC1, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'S' - S
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x7E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |.XXXXX......... */ 0x7E, 0x00,
    /*7 |......X........ */ 0x01, 0x00,
    /*8 |......X........ */ 0x01, 0x00,
    /*9 |......X........ */ 0x01, 0x00,
    /*A |X.....X........ */ 0x41, 0x00,
    /*B O.XXXXX......... */ 0xBE, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'T' - T
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXXX........ */ 0x7F, 0x00,
    /*2 |...X........... */ 0x08, 0x00,
    /*3 |...X........... */ 0X08, 0x00,
    /*4 |...X........... */ 0x08, 0x00,
    /*5 |...X........... */ 0X08, 0x00,
    /*6 |...X........... */ 0x08, 0x00,
    /*7 |...X........... */ 0x08, 0x00,
    /*8 |...X........... */ 0x08, 0x00,
    /*9 |...X........... */ 0x08, 0x00,
    /*A |...X........... */ 0x08, 0x00,
    /*B O...X........... */ 0x88, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'U' - U
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 |X.....X........ */ 0x41, 0x00,
    /*8 |X.....X........ */ 0x41, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A |X.....X........ */ 0x41, 0x00,
    /*B O.XXXXX......... */ 0xBE, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'V' - V
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |.X...X......... */ 0x22, 0x00,
    /*5 |.X...X......... */ 0X22, 0x00,
    /*6 |.X...X......... */ 0x22, 0x00,
    /*7 |..X.X.......... */ 0x14, 0x00,
    /*8 |..X.X.......... */ 0x14, 0x00,
    /*9 |..X.X.......... */ 0x14, 0x00,
    /*A |...X........... */ 0x08, 0x00,
    /*B O...X........... */ 0x88, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'W' - W
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X..X..X........ */ 0x49, 0x00,
    /*5 |X..X..X........ */ 0X49, 0x00,
    /*6 |.X.X.X......... */ 0x2A, 0x00,
    /*7 |.X.X.X......... */ 0x2A, 0x00,
    /*8 |.X.X.X......... */ 0x2A, 0x00,
    /*9 |.X.X.X......... */ 0x2A, 0x00,
    /*A |.XXXXX......... */ 0x3E, 0x00,
    /*B O.X.X.X......... */ 0xAA, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'X' - X
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |.X...X......... */ 0X22, 0x00,
    /*4 |.X...X......... */ 0x22, 0x00,
    /*5 |..X.X.......... */ 0X14, 0x00,
    /*6 |..XXX.......... */ 0x1C, 0x00,
    /*7 |..X.X.......... */ 0x14, 0x00,
    /*8 |.X...X......... */ 0x22, 0x00,
    /*9 |.X...X......... */ 0x22, 0x00,
    /*A |X.....X........ */ 0x41, 0x00,
    /*B OX.....X........ */ 0xC1, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'Y' - Y
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |.X...X......... */ 0X22, 0x00,
    /*4 |.X...X......... */ 0x22, 0x00,
    /*5 |..X.X.......... */ 0X14, 0x00,
    /*6 |..X.X.......... */ 0x14, 0x00,
    /*7 |...X........... */ 0x08, 0x00,
    /*8 |...X........... */ 0x08, 0x00,
    /*9 |...X........... */ 0x08, 0x00,
    /*A |...X........... */ 0x08, 0x00,
    /*B O...X........... */ 0x88, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'Z' - Z
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXXX........ */ 0x7F, 0x00,
    /*2 |......X........ */ 0x01, 0x00,
    /*3 |.....X......... */ 0X02, 0x00,
    /*4 |.....X......... */ 0x02, 0x00,
    /*5 |....X.......... */ 0X04, 0x00,
    /*6 |.XXXXX......... */ 0x3E, 0x00,
    /*7 |..X............ */ 0x10, 0x00,
    /*8 |.X............. */ 0x20, 0x00,
    /*9 |.X............. */ 0x20, 0x00,
    /*A |X.............. */ 0x40, 0x00,
    /*B OXXXXXXX........ */ 0xFF, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'a' - a
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |..XXXX......... */ 0x1E, 0x00,
    /*2 |.X....X........ */ 0x21, 0x00,
    /*3 |......X........ */ 0X01, 0x00,
    /*4 |.XXXXXX........ */ 0x3F, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |X....XX........ */ 0x43, 0x00,
    /*7 O.XXXX.X........ */ 0xBD, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'b' - b
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XX............. */ 0x60, 0x00,
    /*2 |X.............. */ 0x40, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0X40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |XXXXXX......... */ 0x7E, 0x00,
    /*7 |X.....X........ */ 0X41, 0x00,
    /*8 |X.....X........ */ 0X41, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A OXXXXXX......... */ 0xFE, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'c' - c
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 O.XXXXX......... */ 0xBE, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'d' - d
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.....XX........ */ 0x03, 0x00,
    /*2 |......X........ */ 0x01, 0x00,
    /*3 |......X........ */ 0X01, 0x00,
    /*4 |......X........ */ 0X01, 0x00,
    /*5 |......X........ */ 0X01, 0x00,
    /*6 |.XXXXXX........ */ 0x3F, 0x00,
    /*7 |X.....X........ */ 0X41, 0x00,
    /*8 |X.....X........ */ 0x41, 0x00,
    /*9 |X.....X........ */ 0x41, 0x00,
    /*A O.XXXXXX........ */ 0xBF, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'e' - e
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |XXXXXX......... */ 0x7E, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 O.XXXXX......... */ 0xBE, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'f' - f
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |....XX......... */ 0x06, 0x00,
    /*2 |...X..X........ */ 0x09, 0x00,
    /*3 |...X........... */ 0X08, 0x00,
    /*4 |...X........... */ 0X08, 0x00,
    /*5 |...X........... */ 0x08, 0x00,
    /*6 |..XXX.......... */ 0X1C, 0x00,
    /*7 |...X........... */ 0x08, 0x00,
    /*8 |...X........... */ 0x08, 0x00,
    /*9 O...X........... */ 0x88, 0x00,
    /*A |...X........... */ 0x08, 0x00,
    /*B |X..X........... */ 0x08, 0x00,
    /*C O.XX............ */ 0xB0, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'g' - g
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 O.XXXXXX........ */ 0xBF, 0x00,
    /*7 |......X........ */ 0X01, 0x00,
    /*8 |..XX..X........ */ 0x19, 0x00,
    /*9 |.X....X........ */ 0x21, 0x00,
    /*A O..XXXX......... */ 0x9E, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'h' - h
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XX............. */ 0x60, 0x00,
    /*2 |X.............. */ 0x40, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0X40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |XXXXXX......... */ 0x7E, 0x00,
    /*7 |X.....X........ */ 0X41, 0x00,
    /*8 |X.....X........ */ 0X41, 0x00,
    /*9 |X.....X........ */ 0X41, 0x00,
    /*A |X.....X........ */ 0x41, 0x00,
    /*B OX.....X........ */ 0xC1, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'i' - i
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |...XX.......... */ 0x0C, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |..XXX.......... */ 0X1C, 0x00,
    /*4 |....X.......... */ 0x04, 0x00,
    /*5 |....X.......... */ 0X04, 0x00,
    /*6 |....X.......... */ 0X04, 0x00,
    /*7 |....X.......... */ 0x04, 0x00,
    /*8 O.XXXXXX........ */ 0xBF, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'j' - j
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |....XX......... */ 0x06, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |...XXX......... */ 0X0E, 0x00,
    /*4 |.....X......... */ 0X02, 0x00,
    /*5 O.....X......... */ 0x82, 0x00,
    /*6 |.....X......... */ 0X02, 0x00,
    /*7 |.....X......... */ 0x02, 0x00,
    /*8 |.X...X......... */ 0x22, 0x00,
    /*9 O..XXX.......... */ 0x9C, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'k' - k
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XX............. */ 0x60, 0x00,
    /*2 |X.............. */ 0x40, 0x00,
    /*3 |X.............. */ 0x40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X...XX......... */ 0X46, 0x00,
    /*6 |X..X........... */ 0x48, 0x00,
    /*7 |XXX............ */ 0X70, 0x00,
    /*8 |XXX............ */ 0X70, 0x00,
    /*9 |X..X........... */ 0x48, 0x00,
    /*A OX...XXX........ */ 0xC7, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'l' - l
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |..XXX.......... */ 0x1C, 0x00,
    /*2 |....X.......... */ 0x04, 0x00,
    /*3 |....X.......... */ 0X04, 0x00,
    /*4 |....X.......... */ 0x04, 0x00,
    /*5 |....X.......... */ 0x04, 0x00,
    /*6 |....X.......... */ 0x04, 0x00,
    /*7 |....X.......... */ 0X04, 0x00,
    /*8 |....X.......... */ 0x04, 0x00,
    /*9 O.XXXXXX........ */ 0xBF, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'m' - m
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXX.XX......... */ 0x76, 0x00,
    /*2 |X..X..X........ */ 0x49, 0x00,
    /*3 |X..X..X........ */ 0X49, 0x00,
    /*4 |X..X..X........ */ 0x49, 0x00,
    /*5 |X..X..X........ */ 0X49, 0x00,
    /*6 |X..X..X........ */ 0x49, 0x00,
    /*7 OX..X..X........ */ 0xC9, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'n' - n
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXX......... */ 0x7E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 OX.....X........ */ 0xC1, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'o' - o
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.....X........ */ 0X41, 0x00,
    /*4 |X.....X........ */ 0x41, 0x00,
    /*5 |X.....X........ */ 0X41, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 O.XXXXX......... */ 0xBE, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'p' - p
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |.X....X........ */ 0x21, 0x00,
    /*3 |.X....X........ */ 0x21, 0x00,
    /*4 |.X....X........ */ 0x21, 0x00,
    /*5 |.X....X........ */ 0X21, 0x00,
    /*6 |.X....X........ */ 0X21, 0x00,
    /*7 O.XXXXX......... */ 0xBE, 0x00,
    /*8 |.X............. */ 0X20, 0x00,
    /*9 |.X............. */ 0x20, 0x00,
    /*A |.X............. */ 0x20, 0x00,
    /*B OXX............. */ 0xE0, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'q' - q
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |X....X......... */ 0x42, 0x00,
    /*4 |X....X......... */ 0X42, 0x00,
    /*5 |X....X......... */ 0X42, 0x00,
    /*6 |X....X......... */ 0X42, 0x00,
    /*7 O.XXXXX......... */ 0xBE, 0x00,
    /*8 |.....X......... */ 0X02, 0x00,
    /*9 |.....X......... */ 0x02, 0x00,
    /*A |.....X......... */ 0x02, 0x00,
    /*B O.....XX........ */ 0x83, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'r' - r
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.X.XXX......... */ 0x2E, 0x00,
    /*2 |.XX...X........ */ 0x31, 0x00,
    /*3 |.X............. */ 0X20, 0x00,
    /*4 |.X............. */ 0x20, 0x00,
    /*5 |.X............. */ 0X20, 0x00,
    /*6 |.X............. */ 0x20, 0x00,
    /*7 OXXX............ */ 0xF0, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'s' - s
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |.XXXXX......... */ 0x3E, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |.XXXXX......... */ 0x3E, 0x00,
    /*5 |......X........ */ 0X01, 0x00,
    /*6 |X.....X........ */ 0x41, 0x00,
    /*7 O.XXXXX......... */ 0xBE, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'t' - t
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |..X............ */ 0x10, 0x00,
    /*2 |..X............ */ 0x10, 0x00,
    /*3 |..X............ */ 0X10, 0x00,
    /*4 |XXXXX.......... */ 0x7C, 0x00,
    /*5 |..X............ */ 0X10, 0x00,
    /*6 |..X............ */ 0X10, 0x00,
    /*7 |..X............ */ 0X10, 0x00,
    /*8 |..X............ */ 0X10, 0x00,
    /*9 |..X...X........ */ 0x11, 0x00,
    /*A O...XXX......... */ 0x8E, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'u' - u 
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X....X......... */ 0x42, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |X....X......... */ 0X42, 0x00,
    /*4 |X....X......... */ 0x42, 0x00,
    /*5 |X....X......... */ 0X42, 0x00,
    /*6 |X....X......... */ 0x42, 0x00,
    /*7 O.XXXXXX........ */ 0xBF, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'v' - v
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XX...XX........ */ 0x63, 0x00,
    /*2 |.X...X......... */ 0x22, 0x00,
    /*3 |.X...X......... */ 0X22, 0x00,
    /*4 |..X.X.......... */ 0x14, 0x00,
    /*5 |..X.X.......... */ 0X14, 0x00,
    /*6 |...X........... */ 0x08, 0x00,
    /*7 O...X........... */ 0x88, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'w' - w
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |X.....X........ */ 0x41, 0x00,
    /*3 |X..X..X........ */ 0X49, 0x00,
    /*4 |.X.X.X......... */ 0x2A, 0x00,
    /*5 |.X.X.X......... */ 0X2A, 0x00,
    /*6 |.XXXXX......... */ 0x3E, 0x00,
    /*7 O.X.X.X......... */ 0xAA, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'x' - x
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X.....X........ */ 0x41, 0x00,
    /*2 |.X...X......... */ 0x22, 0x00,
    /*3 |..X.X.......... */ 0X14, 0x00,
    /*4 |...X........... */ 0x08, 0x00,
    /*5 |..X.X.......... */ 0X14, 0x00,
    /*6 |.X...X......... */ 0x22, 0x00,
    /*7 OX.....X........ */ 0xC1, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'y' - y
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |X....X......... */ 0x42, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |X....X......... */ 0x42, 0x00,
    /*4 |X....X......... */ 0x42, 0x00,
    /*5 |X....X......... */ 0X42, 0x00,
    /*6 O.XXXXX......... */ 0xBE, 0x00,
    /*7 |.....X......... */ 0X02, 0x00,
    /*8 |.....X......... */ 0x02, 0x00,
    /*9 |.....X......... */ 0x02, 0x00,
    /*A O..XXX.......... */ 0x9C, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'z' - z
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A______O________ */ 0x81, 0x00,
    /*1 |XXXXXXX........ */ 0x3F, 0x00,
    /*2 |.....X......... */ 0x02, 0x00,
    /*3 |....X.......... */ 0X04, 0x00,
    /*4 |..XXX.......... */ 0x1C, 0x00,
    /*5 |..X............ */ 0X10, 0x00,
    /*6 |.X............. */ 0x20, 0x00,
    /*7 OXXXXXXX........ */ 0xFF, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },
}; 

#endif  //a_ __A_CSENG_H__
