// a_csnum.h           
//
// Numbers and symbols
//a_NOTE: NUM is the common item that can be used in a macro assign!
//a_NOTE: A in the diagrams means always set to 1, as in (0,0) of every character

#ifndef CSET_NUM

//a_Constants and MACROs
#include "a_predef.h"

#pragma message( "Including " __FILE__ )

#define CSET_NUM                0x1      //a_Let the ACharSetList know it is included for use
#define CSET_TYPE_NUM           'N'      //a_CharSet identifier
#define CSET_MAPSIZE_NUM        28       //a_# of arrays and hence map entries
#define CSET_ARRAYSIZE_NUM      32       //a_32 BYTEs per character array
#define CSET_CHARSIZE_X_NUM     16       //a_Width; including first column for info
#define CSET_CHARSIZE_Y_NUM     16       //a_Height; including the first row for info
#define CSET_CHARBASELINE_NUM   16       //a_Suggested baseline for all characters (from top)
#define CSET_CHARLINEHEIGHT_NUM 16       //a_Suggested height of the line to include all characters without clipping

static BYTE BYTEARRAY_MAP_NUM[CSET_MAPSIZE_NUM + 0x1]  = " 0123456789.,:;-+/*()[]{}_=$";

//a_Each entry is a 16x16 bits
//a_Row 0 contains 1 bit for the rightmost X coordinate
//a_Column 0 contains 2 set bits, first for the baseline and second for lowest Y coordinate
//a_ if only one found, both assumed to be equal
//a_Baseline is used to align characters that are Y osition dependent (ie. sub/super script, lowecase, etc...)
//a_The actual character starts at (1,1) not (0,0), so actual usable size is actually 15x15
//a_First row and column will be zeroed out to provide spacing of 1 bit in X and Y
static BYTE BYTEMATRIX_CHARSET_NUM[CSET_MAPSIZE_NUM][CSET_ARRAYSIZE_NUM] =
{
  //a_' ' -   (space)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 O............... */ 0x80, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |............... */ 0X00, 0x00,
    /*4 |............... */ 0x00, 0x00,
    /*5 |............... */ 0X00, 0x00,
    /*6 |............... */ 0x00, 0x00,
    /*7 |............... */ 0x00, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },


  //a_'0' - 0
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |..XX........... */ 0x18, 0x00,
    /*2 |.X..X.......... */ 0x24, 0x00,
    /*3 |X....X......... */ 0X42, 0x00,
    /*4 |X....X......... */ 0x42, 0x00,
    /*5 OX....X......... */ 0XC2, 0x00,
    /*6 |.X..X.......... */ 0x24, 0x00,
    /*7 O..XX........... */ 0x98, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'1' - 1
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |...X........... */ 0x18, 0x00,
    /*2 |..XX........... */ 0x18, 0x00,
    /*3 |.X.X........... */ 0X28, 0x00,
    /*4 |...X........... */ 0x08, 0x00,
    /*5 O...X........... */ 0x88, 0x00,
    /*6 |...X........... */ 0x08, 0x00,
    /*7 OXXXXXX......... */ 0xFE, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

    //a_'2' - 2
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |.XXXX.......... */ 0x3C, 0x00,
    /*2 |X....X ........ */ 0x42, 0x00,
    /*3 |.....X......... */ 0x02, 0x00,
    /*4 |.XXXX.......... */ 0X3C, 0x00,
    /*5 OX.............. */ 0xC0, 0x00,
    /*6 |X.............. */ 0x40, 0x00,
    /*7 OXXXXXX......... */ 0xFE, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'3 - 3
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |.XXXX.......... */ 0x3C, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |.....X......... */ 0X02, 0x00,
    /*4 |..XXX.......... */ 0x1C, 0x00,
    /*5 O.....X......... */ 0X82, 0x00,
    /*6 |X....X......... */ 0x42, 0x00,
    /*7 O.XXXX.......... */ 0xBC, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'4 - 4
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |....XX......... */ 0x06, 0x00,
    /*2 |...X.X......... */ 0x0A, 0x00,
    /*3 |..X..X......... */ 0X12, 0x00,
    /*4 |.X...X......... */ 0x22, 0x00,
    /*5 OXXXXXX......... */ 0XFE, 0x00,
    /*6 |.....X......... */ 0x02, 0x00,
    /*7 O.....X......... */ 0x82, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'5' - 5
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |XXXXXX......... */ 0x7E, 0x00,
    /*2 |X.............. */ 0x40, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |XXXXX.......... */ 0x7C, 0x00,
    /*5 O.....X......... */ 0X82, 0x00,
    /*6 |.....X......... */ 0x02, 0x00,
    /*7 OXXXXX.......... */ 0xFC, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'6' - 6
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |.XXXX.......... */ 0x3C, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |XXXXX.......... */ 0x7C, 0x00,
    /*5 OX....X......... */ 0XC2, 0x00,
    /*6 |X....X......... */ 0x42, 0x00,
    /*7 O.XXXX.......... */ 0xBC, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'7' - 7
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |XXXXXX......... */ 0x7E, 0x00,
    /*2 |.....X......... */ 0x02, 0x00,
    /*3 |....X.......... */ 0X04, 0x00,
    /*4 |.XXXX.......... */ 0x3C, 0x00,
    /*5 O..X............ */ 0X90, 0x00,
    /*6 |..X............ */ 0x10, 0x00,
    /*7 O..X............ */ 0x90, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'8' - 8
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |.XXXX.......... */ 0x3C, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |X....X......... */ 0X42, 0x00,
    /*4 |.XXXX.......... */ 0x3C, 0x00,
    /*5 OX....X......... */ 0XC2, 0x00,
    /*6 |X....X......... */ 0x42, 0x00,
    /*7 O.XXXX.......... */ 0xBC, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'9' - 9
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_____O_________ */ 0x82, 0x00,
    /*1 |.XXXX.......... */ 0x3C, 0x00,
    /*2 |X....X......... */ 0x42, 0x00,
    /*3 |X....X......... */ 0X42, 0x00,
    /*4 |.XXXXX......... */ 0x3E, 0x00,
    /*5 O.....X......... */ 0X82, 0x00,
    /*6 |X....X......... */ 0x42, 0x00,
    /*7 O.XXXX.......... */ 0xBC, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'.' - . (period)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_O_____________ */ 0xA0, 0x00,
    /*1 O............... */ 0x80, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |XX............. */ 0X60, 0x00,
    /*4 OXX............. */ 0xE0, 0x00,
    /*5 |............... */ 0X00, 0x00,
    /*6 |............... */ 0x00, 0x00,
    /*7 |............... */ 0x00, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_',' - , (comma)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A__O____________ */ 0x90, 0x00,
    /*1 O............... */ 0x80, 0x00,
    /*2 |XX............. */ 0x60, 0x00,
    /*3 |XX............. */ 0X60, 0x00,
    /*4 |.X............. */ 0x20, 0x00,
    /*5 OX.............. */ 0XC0, 0x00,
    /*6 |............... */ 0x00, 0x00,
    /*7 |............... */ 0x00, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'.' - . (period)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_O_____________ */ 0xA0, 0x00,
    /*1 |XX............. */ 0X60, 0x00,
    /*2 |XX............. */ 0x60, 0x00,
    /*3 O............... */ 0x80, 0x00,
    /*4 |XX............. */ 0X60, 0x00,
    /*5 OXX............. */ 0xE0, 0x00,
    /*6 |............... */ 0X00, 0x00,
    /*7 |............... */ 0x00, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_',' - , (comma)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A_O_____________ */ 0xA0, 0x00,
    /*1 |XX............. */ 0x60, 0x00,
    /*2 |XX............. */ 0x60, 0x00,
    /*3 O............... */ 0x80, 0x00,
    /*4 |XX............. */ 0x60, 0x00,
    /*5 |XX............. */ 0X60, 0x00,
    /*6 |.X............. */ 0x20, 0x00,
    /*7 OX.............. */ 0XC0, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'-' - - (minus)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 OXXXXX.......... */ 0XFC, 0x00,
    /*4 |............... */ 0x00, 0x00,
    /*5 |............... */ 0X00, 0x00,
    /*6 O............... */ 0x80, 0x00,
    /*7 |............... */ 0x00, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'+' - + (plus)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |..X............ */ 0X10, 0x00,
    /*4 |..X............ */ 0x10, 0x00,
    /*5 OXXXXX.......... */ 0XFC, 0x00,
    /*6 |..X............ */ 0x10, 0x00,
    /*7 |..X............ */ 0x10, 0x00,
    /*8 O............... */ 0x80, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'*' - * (multiplication)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A___O___________ */ 0x88, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |X..X........... */ 0X48, 0x00,
    /*4 O.XX............ */ 0xB0, 0x00,
    /*5 |X..X........... */ 0X48, 0x00,
    /*6 |............... */ 0x00, 0x00,
    /*7 O............... */ 0x80, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'/' - / (division/forward slash)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 |....X.......... */ 0x04, 0x00,
    /*2 |...X........... */ 0x08, 0x00,
    /*3 |...X........... */ 0X08, 0x00,
    /*4 |..X............ */ 0x10, 0x00,
    /*5 O..X............ */ 0X90, 0x00,
    /*6 |.X............. */ 0x20, 0x00,
    /*7 |.X............. */ 0x20, 0x00,
    /*8 OX.............. */ 0xC0, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'(' - ( (left paranthesis)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A___O___________ */ 0x88, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |..X............ */ 0x10, 0x00,
    /*3 |.X............. */ 0X20, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |X.............. */ 0x40, 0x00,
    /*7 OX.............. */ 0xC0, 0x00,
    /*8 |X.............. */ 0x40, 0x00,
    /*9 |.X............. */ 0x20, 0x00,
    /*A O..X............ */ 0x90, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_')' - ) (right paranthesis)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A___O___________ */ 0x88, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |.X............. */ 0x20, 0x00,
    /*3 |..X............ */ 0X10, 0x00,
    /*4 |...X........... */ 0x08, 0x00,
    /*5 |...X........... */ 0X08, 0x00,
    /*6 |...X........... */ 0x08, 0x00,
    /*7 O...X........... */ 0x88, 0x00,
    /*8 |...X........... */ 0x08, 0x00,
    /*9 |..X............ */ 0x10, 0x00,
    /*A O.X............. */ 0xA0, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'[' - [ (left braket)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A___O___________ */ 0x88, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |XXX............ */ 0x70, 0x00,
    /*3 |X.............. */ 0X40, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |X.............. */ 0X40, 0x00,
    /*6 |X.............. */ 0x40, 0x00,
    /*7 OX.............. */ 0xC0, 0x00,
    /*8 |X.............. */ 0x40, 0x00,
    /*9 |X.............. */ 0x40, 0x00,
    /*A OXXX............ */ 0xF0, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_']' - ] (right braket)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A___O___________ */ 0x88, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |.XXX........... */ 0x38, 0x00,
    /*3 |...X........... */ 0X08, 0x00,
    /*4 |...X........... */ 0x08, 0x00,
    /*5 |...X........... */ 0X08, 0x00,
    /*6 |...X........... */ 0x08, 0x00,
    /*7 O...X........... */ 0x88, 0x00,
    /*8 |...X........... */ 0x08, 0x00,
    /*9 |...X........... */ 0x08, 0x00,
    /*A O.XXX........... */ 0xB8, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'{' - { (left brace)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |..XX........... */ 0x18, 0x00,
    /*3 |.X............. */ 0X20, 0x00,
    /*4 |.X............. */ 0x20, 0x00,
    /*5 |.X............. */ 0X20, 0x00,
    /*6 |X.............. */ 0x40, 0x00,
    /*7 O.X............. */ 0xA0, 0x00,
    /*8 |.X............. */ 0x20, 0x00,
    /*9 |.X............. */ 0x20, 0x00,
    /*A O..XX........... */ 0x98, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'}' - } (right brace)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |.XX............ */ 0x30, 0x00,
    /*3 |...X........... */ 0X08, 0x00,
    /*4 |...X........... */ 0x08, 0x00,
    /*5 |...X........... */ 0X08, 0x00,
    /*6 |....X.......... */ 0x04, 0x00,
    /*7 O...X........... */ 0x88, 0x00,
    /*8 |...X........... */ 0x08, 0x00,
    /*9 |...X........... */ 0x08, 0x00,
    /*A O.XX............ */ 0xB0, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'_' - _ (under_score)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 O............... */ 0x80, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |............... */ 0X00, 0x00,
    /*4 OXXXXX.......... */ 0xFC, 0x00,
    /*5 |............... */ 0X00, 0x00,
    /*6 |............... */ 0x00, 0x00,
    /*7 |............... */ 0x00, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'=' - = (equals)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 |............... */ 0x00, 0x00,
    /*2 |............... */ 0x00, 0x00,
    /*3 |XXXXX.......... */ 0X7C, 0x00,
    /*4 O............... */ 0x80, 0x00,
    /*5 |XXXXX.......... */ 0X7C, 0x00,
    /*6 |............... */ 0x00, 0x00,
    /*7 O............... */ 0x80, 0x00,
    /*8 |............... */ 0x00, 0x00,
    /*9 |............... */ 0x00, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

  //a_'$' - $ (dollar, dollar bill y'all...)
  {
    /*  0123456789ABCDEF     BitNumber*/
    /*  8421842184218421     BitValues*/ 
    /*0 A____O__________ */ 0x84, 0x00,
    /*1 |..X............ */ 0x10, 0x00,
    /*2 |.XXX........... */ 0x38, 0x00,
    /*3 |X...X.......... */ 0X44, 0x00,
    /*4 |X.............. */ 0x40, 0x00,
    /*5 |.XXX........... */ 0X38, 0x00,
    /*6 |....X.......... */ 0x04, 0x00,
    /*7 OX...X.......... */ 0xC4, 0x00,
    /*8 |.XXX........... */ 0x38, 0x00,
    /*9 O..X............ */ 0x90, 0x00,
    /*A |............... */ 0x00, 0x00,
    /*B |............... */ 0x00, 0x00,
    /*C |............... */ 0x00, 0x00,
    /*D |............... */ 0x00, 0x00,
    /*E |............... */ 0x00, 0x00,
    /*F |............... */ 0x00, 0x00
  },

};

#endif
